@@ -196,6 +196,7 @@ gsm_color_button_class_init (GSMColorButtonClass * klass)
 				   PROP_PERCENTAGE,
 				   g_param_spec_double ("fraction",
 							_("Fraction"),
+                            // TRANSLATORS: description of the pie color picker's (mem, swap) filled percentage property
 							_("Percentage full for pie color pickers"),
 							0, 1, 0.5,
 							G_PARAM_READWRITE));
@@ -261,7 +262,7 @@ fill_image_buffer_from_file (cairo_t *cr, const char *filePath)
   tmp_cr = cairo_create (tmp_surface);
   rsvg_handle_render_cairo (handle, tmp_cr);
   cairo_destroy (tmp_cr);
-  rsvg_handle_free (handle);
+  g_object_unref (handle);
   return tmp_surface;
 }
 
